@@ -21,8 +21,7 @@
 #include <ucommon/export.h>
 #include <ccaudio2.h>
 
-using namespace UCOMMON_NAMESPACE;
-
+namespace ucommon {
 
 AudioBase::AudioBase()
 {
@@ -55,4 +54,5 @@ ssize_t AudioBase::getNative(Encoded data, size_t bytes)
     return result;
 }
 
+} // namespace ucommon
 
