@@ -22,7 +22,7 @@
 #include <ucommon/export.h>
 #include <ccaudio2.h>
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 TelTone::TelTone(tonekey_t *k, Level l, timeout_t duration) :
 AudioTone(duration)
@@ -91,3 +91,5 @@ Audio::Linear TelTone::getFrame(void)
 
     return AudioTone::getFrame();
 }
+
+} // namespace ucommon
