@@ -16,9 +16,9 @@
 // along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <ccaudio2.h>
-#include <config.h>
+#include <ccaudio2-config.h>
 
-using namespace UCOMMON_NAMESPACE;
+using namespace ucommon;
 
 static const char *delfile = NULL;
 
@@ -56,7 +56,7 @@ void writeTones(char **argv, bool append)
     AudioTone *tone;
     AudioStream output;
     Audio::Info info, make;
-    const char *target;
+    const char *target = NULL;
     char *option;
     char *offset = NULL;
     char *encoding = (char *)"pcmu";
@@ -65,7 +65,7 @@ void writeTones(char **argv, bool append)
     timeout_t maxtime = 60000;
     unsigned maxframes;
     Audio::Linear buffer;
-    char *filename = (char *)"tones.conf";
+    const char *filename = DEFAULT_CFGPATH;
 
 retry:
     option = *argv;
@@ -219,7 +219,7 @@ skip:
 
 void listTones(char **argv)
 {
-    const char *filename = "tones.conf";
+    const char *filename = DEFAULT_CFGPATH;
     const char *locale = NULL;
     const char *option;
     TelTone::tonekey_t *key;
